Module: Recourse::Routing
- Defined in:
- lib/recourse/routing.rb
Overview
Makes Recourse methods like recourses available in config/routes.rb
Instance Method Summary collapse
-
#recourses(*args, **kwargs, &block) ⇒ Object
This method is equivalent to Rails
resourceswith the added bonus that we store the name of these administered resources so we can display them to admins in the navbar.
Instance Method Details
#recourses(*args, **kwargs, &block) ⇒ Object
This method is equivalent to Rails resources with the added bonus that we store
the name of these administered resources so we can display them to admins in the navbar.
7 8 9 10 |
# File 'lib/recourse/routing.rb', line 7 def recourses(*args, **kwargs, &block) store_recourses args, kwargs resources(*args, **kwargs, &scoped(args, &block)) end |