Module: RecoursiveHelper

Defined in:
app/helpers/recoursive_helper.rb

Overview

A collection of helper methods used for navigation link in the admin-only section

Instance Method Summary collapse

Instance Method Details

Adds a link next to the title to add a new resource.



4
5
6
# File 'app/helpers/recoursive_helper.rb', line 4

def button_link_to_add(name, path)
  content_for(:edit) { button_link_to "Add #{name}", path, class: 'btn-sm btn-outline ms-3' }
end